@@ -2,10 +2,6 @@
 r"""
 Elements, parents, and categories in Sage: a primer
 
-.. contents::
-   :depth: 2
-   :class: this-will-duplicate-information-and-it-is-still-useful-here
-
 Abstract
 ========
 
@@ -84,7 +80,7 @@ Some challenges
 
       sage: A = random_matrix(ZZ, 6, 3, x=7)                                            # needs sage.modules
       sage: L = LatticePolytope(A.rows())                                               # needs sage.geometry.polyhedron sage.modules
-      sage: L.npoints()                # oops!   # random                               # needs palp sage.geometry.polyhedron sage.modules
+      sage: L.n_points()                # oops!   # random                              # needs palp sage.geometry.polyhedron sage.modules
       37
 
 - How to ensure robustness?
@@ -128,7 +124,8 @@ Sage knows about monoids::
 
 and sure enough, binary powering is defined there::
 
-    sage: m._pow_int.__module__                                                         # needs sage.modules
+    sage: # needs sage.modules, known bug: windows (crash - https://github.com/passagemath/passagemath/issues/1892#issuecomment-3673607183)
+    sage: m._pow_int.__module__
     'sage.categories.monoids'
 
 That's our bookshelf! And it's used in many places::
@@ -825,10 +822,10 @@ element of the parent?)::
       running ._test_not_implemented_methods() . . . pass
       running ._test_pickling() . . . pass
       pass
-        running ._test_elements_eq_reflexive() . . . pass
-        running ._test_elements_eq_symmetric() . . . pass
-        running ._test_elements_eq_transitive() . . . pass
-        running ._test_elements_neq() . . . pass
+    running ._test_elements_eq_reflexive() . . . pass
+    running ._test_elements_eq_symmetric() . . . pass
+    running ._test_elements_eq_transitive() . . . pass
+    running ._test_elements_neq() . . . pass
     running ._test_enumerated_set_contains() . . . pass
     running ._test_enumerated_set_iter_cardinality() . . . pass
     running ._test_enumerated_set_iter_list() . . . pass
@@ -836,6 +833,8 @@ element of the parent?)::
     running ._test_new() . . . pass
     running ._test_not_implemented_methods() . . . pass
     running ._test_pickling() . . . pass
+    running ._test_random() . . . pass
+    running ._test_rank() . . . pass
     running ._test_some_elements() . . . pass
 
 Tests can be run individually::
@@ -931,6 +930,7 @@ Where do all the operations on ``S`` and its elements come from?
 to use Sage's introspection tools to recover where it's implemented::
 
     sage: x._repr_.__module__
+    'sage.structure.element_wrapper'
     sage: sage.misc.sageinspect.sage_getfile(x._repr_)
     '.../sage/structure/element_wrapper.pyx'
 
